# pytentiostat
python code for the JUAMI potentiostat

The JUAMI potentiostat is a low-cost potentiostat, for classroom demonstrations and simple lab potentiostat experiments, that is built on the Arduino platform.  

This project is to build a Python API for controlling the potentiostat.

For more info about JUAMI: http://www.juami.org/
For more questions about the pytentionstat project: Austin Plymill: austinplymill2021@u.northwestern.edu
                                                    Simon Billinge: sb2896@columbia.edu
